import { adroll } from './src/adroll'
import { bizible } from './src/bizible'
import { demandbase } from './src/demandbase'
import { eloqua } from './src/eloqua'
import { intercom } from './src/intercom'
import { segment } from './src/segment'
import { session } from './src/session'
import { tagManager } from './src/tag-manager'

export default function initIntegrationBroker (config = {}) {
  if (typeof window === 'undefined') return {}

  const {
    exclude = [],

    demandbase: demandbaseKey,
    bizible: bizibleTrigger,
    tagManager: tagManagerTrigger,

    adroll: adrollKeys,
    eloqua: eloquaKey,
    intercom: intercomKey,
    segment: segmentKey
  } = config

  if (isExcluded(exclude)) return {}

  if (bizibleTrigger !== false) bizible.load()
  if (tagManagerTrigger !== false) tagManager()

  if (adrollKeys) adroll.load(adrollKeys)
  if (demandbaseKey) demandbase.load(demandbaseKey)
  if (eloquaKey) eloqua.load(eloquaKey)
  if (intercomKey) intercom.load(intercomKey)

  if (segmentKey) {
    segment.load(segmentKey)
    segment.page()
  }

  session()

  return {
    adroll: window.adroll,
    session,
    segment,
    bizible: window.Bizible,
    demandbase,
    eloqua,
    intercom: window.Intercom,
    doTaxes: () => window.open('https://www.google.com/search?q=quickbooks', '_tab')
  }
}

function isExcluded (exclude) {
  const { pathname } = window.location

  if (exclude.filter(function (item) {
    return typeof item === 'string'
      ? pathname.indexOf(item) === 0
      : item.test(pathname)
  }).length > 0) return true
}
